@@ -111,12 +111,12 @@ create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **pat
 	ClutterActor *marker;
 	ClutterActor *layer_actor;
 	ClutterColor city_color = { 0x10, 0x10, 0x10, 0xbb };
-	ClutterColor city_a_color = { 0x1c, 0x5e, 0xb4, 0xbb };
-	ClutterColor city_b_color = { 0x25, 0xa0, 0x67, 0xbb };
-	ClutterColor city_c_color = { 0xe4, 0xa3, 0x09, 0xbb };
-	ClutterColor city_d_color = { 0xc6, 0x45, 0x01, 0xbb };
-	ClutterColor city_e_color = { 0xa5, 0x1b, 0x2b, 0xbb };
-	ClutterColor city_f_color = { 0x61, 0x35, 0x84, 0xbb };
+	ClutterColor city_a_color = { 0x36, 0x89, 0xe6, 0xbb };
+	ClutterColor city_b_color = { 0xde, 0x3e, 0x80, 0xbb };
+	ClutterColor city_c_color = { 0xa5, 0x6d, 0xe2, 0xbb };
+	ClutterColor city_d_color = { 0x71, 0x53, 0x44, 0xbb };
+	ClutterColor city_e_color = { 0xab, 0xac, 0xae, 0xbb };
+	ClutterColor city_f_color = { 0x48, 0x5a, 0x6c, 0xbb };
 	ClutterColor text_color = { 0xff, 0xff, 0xff, 0xff };
 	LocationCallbackData callback_data;
 	gchar *station = NULL;
